@@ -32,13 +32,13 @@ func TestProcSnmp(t *testing.T) {
 		have float64
 	}{
 		{name: "pid", want: 26231, have: float64(procSnmp.PID)},
-		{name: "IP:Forwarding", want: 2, have: *procSnmp.Ip.Forwarding},
-		{name: "IP:DefaultTTL", want: 64, have: *procSnmp.Ip.DefaultTTL},
-		{name: "Icmp:InMsgs", want: 45, have: *procSnmp.Icmp.InMsgs},
-		{name: "IcmpMsg:InType3", want: 45, have: *procSnmp.IcmpMsg.InType3},
-		{name: "IcmpMsg:OutType3", want: 50, have: *procSnmp.IcmpMsg.OutType3},
-		{name: "TCP:RtoAlgorithm", want: 1, have: *procSnmp.Tcp.RtoAlgorithm},
-		{name: "TCP:RtoMin", want: 200, have: *procSnmp.Tcp.RtoMin},
+		{name: "IP:Forwarding", want: 2, have: *procSnmp.Forwarding},
+		{name: "IP:DefaultTTL", want: 64, have: *procSnmp.DefaultTTL},
+		{name: "Icmp:InMsgs", want: 45, have: *procSnmp.InMsgs},
+		{name: "IcmpMsg:InType3", want: 45, have: *procSnmp.InType3},
+		{name: "IcmpMsg:OutType3", want: 50, have: *procSnmp.OutType3},
+		{name: "TCP:RtoAlgorithm", want: 1, have: *procSnmp.RtoAlgorithm},
+		{name: "TCP:RtoMin", want: 200, have: *procSnmp.RtoMin},
 		{name: "Udp:InDatagrams", want: 10179, have: *procSnmp.Udp.InDatagrams},
 		{name: "Udp:NoPorts", want: 50, have: *procSnmp.Udp.NoPorts},
 		{name: "UdpLite:InDatagrams", want: 0, have: *procSnmp.UdpLite.NoPorts},
