@@ -11,6 +11,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+//go:build linux
 // +build linux
 
 package sysfs
@@ -39,6 +40,7 @@ func TestNVMeClass(t *testing.T) {
 			Model:            "Samsung SSD 970 PRO 512GB",
 			Serial:           "S680HF8N190894I",
 			State:            "live",
+			ControllerID:     "1997",
 		},
 	}
 
